@@ -3,8 +3,9 @@ import json
 import warnings
 from contextlib import contextmanager
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowSkipException
 from dagster import check, seven
+from dagster.cli.api import StepExecutionSkipped
 from dagster.core.instance import AIRFLOW_EXECUTION_DATE_STR, DagsterInstance
 from dagster.grpc.types import ExecuteStepArgs
 from dagster.serdes import deserialize_json_to_dagster_namedtuple, serialize_dagster_namedtuple
@@ -34,8 +35,6 @@ class DagsterDockerOperator(DockerOperator):
         be mapped to tmp_dir. If not provided defaults to using the standard system temp directory.
     """
 
-    # py2 compat
-    # pylint: disable=keyword-arg-before-vararg
     def __init__(self, dagster_operator_parameters, *args):
         kwargs = dagster_operator_parameters.op_kwargs
         tmp_dir = kwargs.pop("tmp_dir", DOCKER_TEMPDIR)
@@ -43,12 +42,18 @@ class DagsterDockerOperator(DockerOperator):
         self.host_tmp_dir = host_tmp_dir
 
         run_config = dagster_operator_parameters.run_config
-        if "filesystem" in run_config["storage"]:
+        if "filesystem" in run_config["intermediate_storage"]:
             if (
-                "config" in (run_config["storage"].get("filesystem", {}) or {})
+                "config" in (run_config["intermediate_storage"].get("filesystem", {}) or {})
                 and "base_dir"
-                in ((run_config["storage"].get("filesystem", {}) or {}).get("config", {}) or {})
-                and run_config["storage"]["filesystem"]["config"]["base_dir"] != tmp_dir
+                in (
+                    (run_config["intermediate_storage"].get("filesystem", {}) or {}).get(
+                        "config", {}
+                    )
+                    or {}
+                )
+                and run_config["intermediate_storage"]["filesystem"]["config"]["base_dir"]
+                != tmp_dir
             ):
                 warnings.warn(
                     "Found base_dir '{base_dir}' set in filesystem storage config, which was not "
@@ -56,25 +61,27 @@ class DagsterDockerOperator(DockerOperator):
                     "'{host_tmp_dir}' from the host). We assume you know what you are doing, but "
                     "if you are having trouble executing containerized workloads, this may be the "
                     "issue".format(
-                        base_dir=run_config["storage"]["filesystem"]["config"]["base_dir"],
+                        base_dir=run_config["intermediate_storage"]["filesystem"]["config"][
+                            "base_dir"
+                        ],
                         tmp_dir=tmp_dir,
                         host_tmp_dir=host_tmp_dir,
                     )
                 )
             else:
-                run_config["storage"]["filesystem"] = dict(
-                    run_config["storage"]["filesystem"] or {},
+                run_config["intermediate_storage"]["filesystem"] = dict(
+                    run_config["intermediate_storage"]["filesystem"] or {},
                     **{
                         "config": dict(
                             (
-                                (run_config["storage"].get("filesystem", {}) or {}).get(
-                                    "config", {}
-                                )
+                                (
+                                    run_config["intermediate_storage"].get("filesystem", {}) or {}
+                                ).get("config", {})
                                 or {}
                             ),
-                            **{"base_dir": tmp_dir}
+                            **{"base_dir": tmp_dir},
                         )
-                    }
+                    },
                 )
 
         self.docker_conn_id_set = kwargs.get("docker_conn_id") is not None
@@ -116,7 +123,7 @@ class DagsterDockerOperator(DockerOperator):
             # just check the last log line to see if it's JSON.
             xcom_all=True,
             *args,
-            **kwargs
+            **kwargs,
         )
 
     @contextmanager
@@ -207,17 +214,14 @@ class DagsterDockerOperator(DockerOperator):
 
         input_json = serialize_dagster_namedtuple(
             ExecuteStepArgs(
-                pipeline_origin=recon_pipeline.get_origin(),
+                pipeline_origin=recon_pipeline.get_python_origin(),
                 pipeline_run_id=self.run_id,
                 instance_ref=self.instance_ref,
-                mode=self.mode,
                 step_keys_to_execute=self.step_keys,
-                run_config=self.run_config,
-                retries_dict={},
             )
         )
 
-        command = "dagster api execute_step_with_structured_logs {}".format(json.dumps(input_json))
+        command = "dagster api execute_step {}".format(json.dumps(input_json))
         self.log.info("Executing: {command}\n".format(command=command))
         return command
 
@@ -237,7 +241,7 @@ class DagsterDockerOperator(DockerOperator):
         if self.docker_conn_id_set:
             return super(DagsterDockerOperator, self).get_hook()
 
-        class _DummyHook(object):
+        class _DummyHook:
             def get_conn(self):
                 return from_env().api
 
@@ -275,11 +279,17 @@ class DagsterDockerOperator(DockerOperator):
 
             try:
                 events = [deserialize_json_to_dagster_namedtuple(line) for line in res if line]
+
             except Exception:  # pylint: disable=broad-except
                 raise AirflowException(
                     "Could not parse response {response}".format(response=repr(res))
                 )
 
+            if len(events) == 1 and isinstance(events[0], StepExecutionSkipped):
+                raise AirflowSkipException(
+                    "Dagster emitted skip event, skipping execution in Airflow"
+                )
+
             check_events_for_failures(events)
             check_events_for_skips(events)
 
