@@ -17,7 +17,7 @@ from dagster_airflow_tests.test_fixtures import (
     execute_tasks_in_dag,
     postgres_instance,
 )
-from dagster_test.test_project import test_project_environments_path
+from dagster_test.test_project import get_test_project_environments_path
 
 from .utils import validate_pipeline_execution, validate_skip_pipeline_execution
 
@@ -27,11 +27,12 @@ def test_fs_storage_no_explicit_base_dir(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = "demo_pipeline"
-    environments_path = test_project_environments_path()
+    environments_path = get_test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
         recon_repo=ReconstructableRepository.for_module(
-            "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo",
+            "dagster_test.test_project.test_pipelines.repo",
+            "define_demo_execution_repo",
         ),
         environment_yaml=[
             os.path.join(environments_path, "env.yaml"),
@@ -47,11 +48,12 @@ def test_fs_storage(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = "demo_pipeline"
-    environments_path = test_project_environments_path()
+    environments_path = get_test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
         recon_repo=ReconstructableRepository.for_module(
-            "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo",
+            "dagster_test.test_project.test_pipelines.repo",
+            "define_demo_execution_repo",
         ),
         environment_yaml=[
             os.path.join(environments_path, "env.yaml"),
@@ -68,11 +70,12 @@ def test_s3_storage(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = "demo_pipeline"
-    environments_path = test_project_environments_path()
+    environments_path = get_test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
         recon_repo=ReconstructableRepository.for_module(
-            "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo",
+            "dagster_test.test_project.test_pipelines.repo",
+            "define_demo_execution_repo",
         ),
         environment_yaml=[
             os.path.join(environments_path, "env.yaml"),
@@ -86,14 +89,16 @@ def test_s3_storage(
 @nettest
 @requires_airflow_db
 def test_gcs_storage(
-    dagster_airflow_docker_operator_pipeline, dagster_docker_image,
+    dagster_airflow_docker_operator_pipeline,
+    dagster_docker_image,
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = "demo_pipeline_gcs"
-    environments_path = test_project_environments_path()
+    environments_path = get_test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
         recon_repo=ReconstructableRepository.for_module(
-            "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo",
+            "dagster_test.test_project.test_pipelines.repo",
+            "define_demo_execution_repo",
         ),
         environment_yaml=[
             os.path.join(environments_path, "env.yaml"),
@@ -109,11 +114,12 @@ def test_skip_operator(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = "optional_outputs"
-    environments_path = test_project_environments_path()
+    environments_path = get_test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
         recon_repo=ReconstructableRepository.for_module(
-            "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo",
+            "dagster_test.test_project.test_pipelines.repo",
+            "define_demo_execution_repo",
         ),
         environment_yaml=[os.path.join(environments_path, "env_filesystem.yaml")],
         op_kwargs={"host_tmp_dir": "/tmp"},
@@ -128,7 +134,7 @@ def test_error_dag_containerized(dagster_docker_image):  # pylint: disable=redef
     recon_repo = ReconstructableRepository.for_module(
         "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo"
     )
-    environments_path = test_project_environments_path()
+    environments_path = get_test_project_environments_path()
     environment_yaml = [
         os.path.join(environments_path, "env_s3.yaml"),
     ]
@@ -162,7 +168,7 @@ def test_airflow_execution_date_tags_containerized(
     recon_repo = ReconstructableRepository.for_module(
         "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo"
     )
-    environments_path = test_project_environments_path()
+    environments_path = get_test_project_environments_path()
     environment_yaml = [
         os.path.join(environments_path, "env_s3.yaml"),
     ]
